<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 1.5                                                |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2006                                  |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the Affero General Public License Version 1,    |
 | March 2002.                                                        |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the Affero General Public License for more details.            |
 |                                                                    |
 | You should have received a copy of the Affero General Public       |
 | License along with this program; if not, contact the Social Source |
 | Foundation at info[AT]socialsourcefoundation[DOT]org.  If you have |
 | questions about the Affero General Public License or the licensing |
 | of CiviCRM, see the Social Source Foundation CiviCRM license FAQ   |
 | at http://www.openngo.org/faqs/licensing.html                       |
 +--------------------------------------------------------------------+
*/

/**
 *
 * @package CRM
 * @author Donald A. Lobo <lobo@yahoo.com>
 * @copyright CiviCRM LLC (c) 2004-2006
 * $Id$
 *
 */


require_once 'CRM/Core/DAO/IMProvider.php';

class CRM_Core_BAO_IMProvider extends CRM_Core_DAO_IMProvider {

    /**
     * class constructor
     */
    function CRM_Core_BAO_IMProvider( ) {
        parent::CRM_Core_DAO_IMProvider( );
    }
    
    /**
     * Takes a bunch of params that are needed to match certain criteria and
     * retrieves the relevant objects. Typically the valid params are only
     * contact_id. We'll tweak this function to be more full featured over a period
     * of time. This is the inverse function of create. It also stores all the retrieved
     * values in the default array
     *
     * @param array $params   (reference ) an assoc array of name/value pairs
     * @param array $defaults (reference ) an assoc array to hold the flattened values
     *
     * @return object CRM_Core_BAO_IMProvider object
     * @access public
     * @static
     */
     function retrieve( &$params, &$defaults ) {
        $imProvider =& new CRM_Core_DAO_IMProvider( );
        $imProvider->copyValues( $params );
        if ( $imProvider->find( true ) ) {
            CRM_Core_DAO::storeValues( $imProvider, $defaults );
            return $imProvider;
        }
        return null;
    }
    
    /**
     * update the is_active flag in the db
     *
     * @param int      $id        id of the database record
     * @param boolean  $is_active value we want to set the is_active field
     *
     * @return Object             DAO object on sucess, null otherwise
     * 
     * @access public
     * @static
     */
     function setIsActive( $id, $is_active ) {
        return CRM_Core_DAO::setFieldValue( 'CRM_Core_DAO_IMProvider', $id, 'is_active', $is_active );
    }
    
    /**
     * Function to delete IMProvider Types 
     * 
     * @param int   $imProviderTypeId      Id of the im provider type to be deleted.
     * 
     * @return void
     * 
     * @access public
     * @static
     */
     function del($imProviderTypeId) 
    {
        require_once 'CRM/Core/DAO/IM.php';
        //check dependencies
        $im = & new CRM_Core_DAO_IM();
        $im->provider_id= $imProviderTypeId;
        $im->delete();
        
        $imProvider = & new CRM_Core_DAO_IMProvider();
        $imProvider->id = $imProviderTypeId;
        $imProvider->delete();
    }
}

?>